@@ -1,7 +1,8 @@
 # from .crowdfund.crowd_fund import *
 # from .farm_army.farm_army import *
 # from .blockchain.eth_api import *
+# from .google_trends.trends import *
 from .four_chan.four_chan import *
-
+from .rss.rss_feed import RSSFeed
 
 
